@@ -24,7 +24,7 @@ use warnings;
 
 ################################################################################
 package CSS::Sass::Plugins;
-our $VERSION = "3.4.7";
+our $VERSION = "3.4.8";
 ################################################################################
 # collect plugins
 our %plugins;
@@ -47,7 +47,7 @@ return \%plugins unless -d $root;
 opendir (my $dh, $root) or
 	die "error querying plugins";
 while (my $item = readdir($dh)) {
-	next unless $item =~ m/^[a-zA-Z]+$/;
+	next unless $item =~ m/^[a-zA-Z\-]+$/;
 	$plugins{$item} = $root . $item
 }
 
