@@ -101,9 +101,12 @@ namespace Sass {
 
     // load plugins and register custom behaviors
     for (auto __plug = (plugin_paths).begin(); __plug != (plugin_paths).end(); ++__plug) { auto plug = *(__plug); plugins.load_plugins(plug); }
-    for (auto __fn = (plugins.get_headers()).begin(); __fn != (plugins.get_headers()).end(); ++__fn) { auto fn = *(__fn); c_headers.push_back(fn); }
-    for (auto __fn = (plugins.get_importers()).begin(); __fn != (plugins.get_importers()).end(); ++__fn) { auto fn = *(__fn); c_importers.push_back(fn); }
-    for (auto __fn = (plugins.get_functions()).begin(); __fn != (plugins.get_functions()).end(); ++__fn) { auto fn = *(__fn); c_functions.push_back(fn); }
+    const std::vector<Sass_Importer_Entry> headers = plugins.get_headers();
+    const std::vector<Sass_Importer_Entry> importers = plugins.get_importers();
+    const std::vector<Sass_Function_Entry> functions = plugins.get_functions();
+    for (auto __fn = (headers).begin(); __fn != (headers).end(); ++__fn) { Sass_Importer_Entry fn = *(__fn); c_headers.push_back(fn); }
+    for (auto __fn = (importers).begin(); __fn != (importers).end(); ++__fn) { Sass_Importer_Entry fn = *(__fn); c_importers.push_back(fn); }
+    for (auto __fn = (functions).begin(); __fn != (functions).end(); ++__fn) { Sass_Function_Entry fn = *(__fn); c_functions.push_back(fn); }
 
     // sort the items by priority (lowest first)
     sort (c_headers.begin(), c_headers.end(), sort_importers);
