@@ -646,10 +646,7 @@ namespace Sass {
             >,
             sequence <
               negate <
-                sequence <
-                  exactly < url_kwd >,
-                  exactly <'('>
-                >
+                uri_prefix
               >,
               neg_class_char <
                 almost_any_value_class
@@ -1050,7 +1047,7 @@ namespace Sass {
 
     /* no longer used - remove?
     const char* rgb_prefix(const char* src) {
-      return word<rgb_kwd>(src);
+      return word<rgb_fn_kwd>(src);
     }*/
     // Match CSS uri specifiers.
 
@@ -1164,7 +1161,7 @@ namespace Sass {
     }
     // Match the CSS negation pseudo-class.
     const char* pseudo_not(const char* src) {
-      return word< pseudo_not_kwd >(src);
+      return word< pseudo_not_fn_kwd >(src);
     }
     // Match CSS 'odd' and 'even' keywords for functional pseudo-classes.
     const char* even(const char* src) {
@@ -1611,7 +1608,7 @@ namespace Sass {
                 sequence <
                   optional < pseudo_prefix >,
                   // fix libsass issue 2376
-                  negate < exactly < url_kwd > >
+                  negate < uri_prefix >
                 >
               >,
               // accept hypens in token
