@@ -232,6 +232,75 @@ namespace Sass {
     return quote_mark;
   }
 
+  std::string read_hex_escapes(const std::string& s)
+  {
+
+    std::string result;
+    bool skipped = false;
+
+    for (size_t i = 0, L = s.length(); i < L; ++i) {
+
+      // implement the same strange ruby sass behavior
+      // an escape sequence can also mean a unicode char
+      if (s[i] == '\\' && !skipped) {
+
+        // remember
+        skipped = true;
+
+        // escape length
+        size_t len = 1;
+
+        // parse as many sequence chars as possible
+        // ToDo: Check if ruby aborts after possible max
+        while (i + len < L && s[i + len] && isxdigit(s[i + len])) ++ len;
+
+        if (len > 1) {
+
+          // convert the extracted hex string to code point value
+          // ToDo: Maybe we could do this without creating a substring
+          uint32_t cp = strtol(s.substr (i + 1, len - 1).c_str(), NULL, 16);
+
+          if (s[i + len] == ' ') ++ len;
+
+          // assert invalid code points
+          if (cp == 0) cp = 0xFFFD;
+          // replace bell character
+          // if (cp == '\n') cp = 32;
+
+          // use a very simple approach to convert via utf8 lib
+          // maybe there is a more elegant way; maybe we shoud
+          // convert the whole output from string to a stream!?
+          // allocate memory for utf8 char and convert to utf8
+          unsigned char u[5] = {0,0,0,0,0}; utf8::append(cp, u);
+          for(size_t m = 0; m < 5 && u[m]; m++) result.push_back(u[m]);
+
+          // skip some more chars?
+          i += len - 1; skipped = false;
+
+        }
+
+        else {
+
+          skipped = false;
+
+          result.push_back(s[i]);
+
+        }
+
+      }
+
+      else {
+
+        result.push_back(s[i]);
+
+      }
+
+    }
+
+    return result;
+
+  }
+
   std::string unquote(const std::string& s, char* qd, bool keep_utf8_sequences, bool strict)
   {
 
